@@ -312,6 +312,13 @@ class PrimitiveGaussian:
         return self
 
     def apply_rotation(self, angle, axis):
+        """
+        apply a rotation with respect to an axis to the function
+
+        :param angle: angle in Radians
+        :param axis: rotation axis
+        :return:
+        """
         from scipy.spatial.transform import Rotation as R
 
         rotation_vector = angle * np.array(axis) / np.linalg.norm(axis)
@@ -360,6 +367,12 @@ class BasisFunction:
         return self
 
     def apply_rotation(self, angle, axis):
+        """
+        apply a rotation with respect to an axis to the function
+        :param angle: angle in Radians
+        :param axis: the axis
+        :return:
+        """
         primitive_gaussians = deepcopy(self.primitive_gaussians)
         for primitive in primitive_gaussians:
             primitive.apply_rotation(angle, axis)
@@ -375,13 +388,19 @@ class BasisFunction:
         return sum([coef * prim.integrate for coef, prim in zip(self.coefficients, self.primitive_gaussians)])
 
     def get_environment_centers(self):
+        """
+        Get an estimation of the molecular geometry by checking the centers of gaussian functions.
+        Different environments (atom types) are distinguished as different gaussian exponents
+        :return: symbols (environments types) and coordinates (gaussian centers)
+        """
+
         unique_center = np.unique(np.array([p.center for p in self.primitive_gaussians]), axis=0)
         data_dict = {}
         coor_dict = {}
 
         for i, center in enumerate(unique_center):
             data = np.where((np.array([p.center for p in self.primitive_gaussians] == center).all(axis=1)))
-            key = tuple(np.array([p.shape for p in self.primitive_gaussians])[data])
+            key = tuple(np.array([p.alpha for p in self.primitive_gaussians])[data])
             if key in data_dict:
                 data_dict[key].append(i)
                 coor_dict[key].append(center)
