@@ -45,11 +45,11 @@ def get_cn(n):
         rotations = ['B', 'B', 'A']
         translations = ['B', 'B', 'A']
     elif n == 3 or n == 4:
-        rotations = ['E', 'E', 'A']
-        translations = ['E', 'E', 'A']
+        rotations = [ 'E', 'A']
+        translations = ['E', 'A']
     else:
-        rotations = ['E1', 'E1', 'A']
-        translations = ['E1', 'E1', 'A']
+        rotations = ['E1', 'A']
+        translations = ['E1', 'A']
 
     name = 'C{}'.format(n)
     #return name, operations, ir_data, rotations, translations, multiplicity
@@ -92,28 +92,28 @@ def get_cnv(n):
             if data.startswith('E'):
                 ir_data_new[data] = pd.Series(list(ir_data_new[data]) + [0])
 
-    multiplicites = ir_data.multiplicities
+    multiplicities = ir_data.multiplicities
     if np.mod(n, 2) == 0:
-        multiplicites += [n//2, n//2]
+        multiplicities += [n//2, n//2]
     else:
-        multiplicites += [n]
+        multiplicities += [n]
 
     if n == 2:
-        rotations = ['B2', 'B2', 'A1']
+        rotations = ['B1', 'B2', 'A2']
         translations = ['B1', 'B2', 'A1']
     elif n == 3 or n == 4:
-        rotations = ['E', 'E', 'A2']
-        translations = ['E', 'E', 'A1']
+        rotations = ['E', 'A2']
+        translations = ['E', 'A1']
     else:
-        rotations = ['E1', 'E1', 'A2']
-        translations = ['E1', 'E1', 'A1']
+        rotations = ['E1', 'A2']
+        translations = ['E1', 'A1']
 
     return CharTable('C{}v'.format(n),
                      operations_new,
                      ir_data_new,
                      rotations=rotations,  # x, y, z
                      translations=translations,  # Rx, Ry, Rz
-                     multiplicities=multiplicites)
+                     multiplicities=multiplicities)
 
 
 def get_cnh(n):
@@ -171,23 +171,23 @@ def get_cnh(n):
             ir_data_new[data] = pd.Series(row)
 
 
-        multiplicites = [1] + [2]*((n-1)//2) + [1, 1] + [2]*((n-1)//2) + [1]
+        multiplicities = [1] + [2]*((n-1)//2) + [1, 1] + [2]*((n-1)//2) + [1]
 
         if n == 2:
             rotations = ['Bu', 'Bu', 'Au']
             translations = ['Bg', 'Bg', 'Ag']
         elif  n == 4:
-            rotations = ['Eu', 'Eu', 'Au']
-            translations = ['Eg', 'Eg', 'Ag']
+            rotations = ['Eu', 'Au']
+            translations = ['Eg', 'Ag']
         else:
-            rotations = ['E1u', 'E1u', 'Au']
-            translations = ['E1g', 'E1g', 'Ag']
+            rotations = ['E1u', 'Au']
+            translations = ['E1g', 'Ag']
     else:
 
         ir_data_new["A'"] = pd.Series(list(ir_data['A']) + [1])
         ir_data_new["A''"] = pd.Series(list(ir_data['A']) + [-1])
 
-        multiplicites = [1] + [2]*((n-1)//2) + [1] + [2]*((n-1)//2)
+        multiplicities = [1] + [2]*((n-1)//2) + [1] + [2]*((n-1)//2)
 
         operations_new += [Reflection(label='sh', axis=[0, 0, 1])]
 
@@ -226,18 +226,18 @@ def get_cnh(n):
             rotations = ["A'", "A'", "A''"]
             translations = ["A''", "A''", "A'"]
         elif n == 3:
-            rotations = ["E'", "E'", "A''"]
-            translations = ["E''", "E''", "A'"]
+            rotations = ["E'", "A''"]
+            translations = ["E''", "A'"]
         else:
-            rotations = ["E1'", "E1'", "A''"]
-            translations = ["E1''", "E1''", "A'"]
+            rotations = ["E1'", "A''"]
+            translations = ["E1''", "A'"]
 
     return CharTable('C{}h'.format(n),
                      operations_new,
                      ir_data_new,
                      rotations=rotations,  # x, y, z
                      translations=translations,  # Rx, Ry, Rz
-                     multiplicities=multiplicites)
+                     multiplicities=multiplicities)
 
 def get_sn(n):
 
@@ -273,11 +273,11 @@ def get_sn(n):
             ir_data.update({label: pd.Series([2] + [real_radical((i+1)*(k+1), n) for k in range(ndim-1)])})
 
         if n == 4:
-            rotations = ['E', 'E', 'A']
-            translations = ['E', 'E', 'B']
+            rotations = ['E', 'A']
+            translations = ['E', 'B']
         else:
-            rotations = ['E1', 'E1', 'A']
-            translations = ['E{}'.format(l//2), 'E{}'.format(l//2), 'B']
+            rotations = ['E1', 'A']
+            translations = ['E{}'.format(l//2), 'B']
 
     else:
 
@@ -338,11 +338,11 @@ def get_sn(n):
             rotations = ['Ag', 'Ag', 'Ag']
             translations = ['Au', 'Au', 'Au']
         elif n == 6:
-            rotations = ['Eg', 'Eg', 'Ag']
-            translations = ['Eu', 'Eu', 'Au']
+            rotations = ['Eg', 'Ag']
+            translations = ['Eu', 'Au']
         else:
-            rotations = ['E1g', 'E1g', 'Ag']
-            translations = ['E1u', 'E1u', 'Au']
+            rotations = ['E1g', 'Ag']
+            translations = ['E1u', 'Au']
 
     return CharTable('S{}'.format(n),
                      operations,
@@ -361,7 +361,8 @@ def get_dn(n):
 
         return CharTable('D2',
                          [Identity(label='E'), Rotation(label='C2', axis=[0, 0, 1], order=2),
-                          Rotation(label="C2'", axis=[0, 1, 0]), Reflection(label="C2''", axis=[1, 0, 0])],
+                          Rotation(label="C2'", axis=[1, 0, 0], order=2),
+                          Rotation(label="C2''", axis=[0, 1, 0], order=2)],
                          {'A1': pd.Series([+1, +1, +1, +1]),
                           'B1': pd.Series([+1, +1, -1, -1]),
                           'B2': pd.Series([+1, -1, -1, +1]),
@@ -377,7 +378,7 @@ def get_dn(n):
     ir_data_new = {}
     ir_data_new['A1'] = pd.Series(list(ir_data['A']) + [ 1])
     ir_data_new['A2'] = pd.Series(list(ir_data['A']) + [-1])
-    operations_new += [Rotation(label="C2'", axis=[0, 1, 0])]
+    operations_new += [Rotation(label="C2'", axis=[0, 1, 0], order=2)]
 
     if 'B' in ir_data:
         ir_data_new['B1'] = pd.Series(list(ir_data['B']) + [ 1, -1])
@@ -386,7 +387,7 @@ def get_dn(n):
         ir_data_new['A1'] = pd.Series(list(ir_data_new['A1']) + [ 1])
         ir_data_new['A2'] = pd.Series(list(ir_data_new['A2']) + [-1])
 
-        operations_new += [Rotation(label="C2''", axis=[1, 0, 0])]
+        operations_new += [Rotation(label="C2''", axis=[np.sin(np.pi/n), np.cos(np.pi/n), 0], order=2)]
 
     for data in ir_data.keys():
         if data.startswith('E'):
@@ -397,28 +398,28 @@ def get_dn(n):
             if data.startswith('E'):
                 ir_data_new[data] = pd.Series(list(ir_data_new[data]) + [0])
 
-    multiplicites = ir_data.multiplicities
+    multiplicities = ir_data.multiplicities
     if np.mod(n, 2) == 0:
-        multiplicites += [n//2, n//2]
+        multiplicities += [n//2, n//2]
     else:
-        multiplicites += [n]
+        multiplicities += [n]
 
     if n == 2:
         rotations = ['B2', 'B2', 'A1']
         translations = ['B1', 'B2', 'A1']
     elif n == 3 or n == 4:
-        rotations = ['E', 'E', 'A2']
-        translations = ['E', 'E', 'A2']
+        rotations = ['E', 'A2']
+        translations = ['E', 'A2']
     else:
-        rotations = ['E1', 'E1', 'A2']
-        translations = ['E1', 'E1', 'A2']
+        rotations = ['E1', 'A2']
+        translations = ['E1', 'A2']
 
     return CharTable('D{}'.format(n),
                      operations_new,
                      ir_data_new,
                      rotations=rotations,  # x, y, z
                      translations=translations,  # Rx, Ry, Rz
-                     multiplicities=multiplicites)
+                     multiplicities=multiplicities)
 
 
 def get_dnh(n):
@@ -431,9 +432,9 @@ def get_dnh(n):
     if n == 2:
         return CharTable('D2h',
                          [Identity(label='E'), Rotation(label='C2', axis=[0, 0, 1], order=2),
-                          Rotation(label="C2'", axis=[0, 1, 0]), Rotation(label="C2''", axis=[1, 0, 0]),
+                          Rotation(label="C2'", axis=[0, 1, 0], order=2), Rotation(label="C2''", axis=[1, 0, 0], order=2),
                           Inversion(label='i'), Reflection(label='sh', axis=[0, 0, 1]),
-                          Reflection(label='sv', axis=[0, 1, 0]), Reflection(label='sd', axis=[1, 0, 0])],
+                          Reflection(label='sv', axis=[1, 0, 0]), Reflection(label='sd', axis=[0, 1, 0])],
                          {'Ag': pd.Series( [+1, +1, +1, +1, +1, +1, +1, +1]),
                           'B1g': pd.Series([+1, +1, -1, -1, +1, +1, -1, -1]),
                           'B2g': pd.Series([+1, -1, -1, +1, +1, -1, +1, -1]),
@@ -464,7 +465,8 @@ def get_dnh(n):
         ir_data_new_u['B2u'] = pd.Series(list(ir_data['B2']) + [-1, -1*l,   1*l, -1*l])
 
         operations_new += [Inversion(label='i'), Reflection(label='sh', axis=[0, 0, 1]),
-                           Reflection(label='s_v', axis=[0, 1, 0]), Reflection(label='sd', axis=[1, 0, 0])]
+                           Reflection(label='s_v', axis=[np.sin(np.pi/n), np.cos(np.pi/n), 0]),
+                           Reflection(label='sd', axis=[0, 1, 0])]
 
         for data in ir_data.keys():
             if data.startswith('E'):
@@ -506,18 +508,18 @@ def get_dnh(n):
                 ir_data_new[data] = pd.Series(row)
 
         #print(((n-1)//2))
-        multiplicites = [1] + [2]*((n-1)//2) + [1]  + [n//2, n//2] + [1] + [2]*((n-1)//2) + [1, n//2, n//2]
+        multiplicities = [1] + [2]*((n-1)//2) + [1]  + [n//2, n//2] + [1] + [2]*((n-1)//2) + [1, n//2, n//2]
 
-        print(multiplicites)
+        # print(multiplicities)
         if n == 2:
             rotations = ['B3g', 'B2g', 'B1g']
             translations = ['B3u', 'B2u', 'B1u']
         elif  n == 4:
-            rotations = ['Eg', 'Eg', 'A2g']
-            translations = ['Eu', 'Eu', 'A2u']
+            rotations = ['Eg', 'A2g']
+            translations = ['Eu', 'A2u']
         else:
-            rotations = ['E1g', 'E1g', 'A2g']
-            translations = ['E1u', 'E1u', 'A2u']
+            rotations = ['E1g', 'A2g']
+            translations = ['E1u', 'A2u']
     else:
 
         ir_data_new["A1'"] = pd.Series(list(ir_data['A1']) + [1, 1])
@@ -526,10 +528,10 @@ def get_dnh(n):
         ir_data_new["A2'"] = pd.Series(list(ir_data['A2']) + [1, -1])
         ir_data_new["A2''"] = pd.Series(list(ir_data['A2']) + [-1, 1])
 
-        multiplicites = [1] + [2]*((n-1)//2) + [n, 1] + [2]*((n-1)//2) + [n]
+        multiplicities = [1] + [2]*((n-1)//2) + [n, 1] + [2]*((n-1)//2) + [n]
 
         operations_new += [Reflection(label='sh', axis=[0, 0, 1]),
-                           Reflection(label='sv', axis=[0, 1, 0])]
+                           Reflection(label='sv', axis=[1, 0, 0])]
 
         for data in ir_data.keys():
             if data.startswith('E'):
@@ -575,18 +577,18 @@ def get_dnh(n):
             rotations = ["A1''", "A2''", "A2'"]
             translations = ["A1'", "A2'", "A2''"]
         elif n == 3:
-            rotations = ["E''", "E''", "A2'"]
-            translations = ["E'", "E'", "A2''"]
+            rotations = ["E''", "A2'"]
+            translations = ["E'", "A2''"]
         else:
-            rotations = ["E1''", "E1''", "A2'"]
-            translations = ["E1'", "E1'", "A2''"]
+            rotations = ["E1''", "A2'"]
+            translations = ["E1'", "A2''"]
 
     return CharTable('D{}h'.format(n),
                      operations_new,
                      ir_data_new,
                      rotations=rotations,  # x, y, z
                      translations=translations,  # Rx, Ry, Rz
-                     multiplicities=multiplicites)
+                     multiplicities=multiplicities)
 
 def get_dnd(n):
 
@@ -606,20 +608,21 @@ def get_dnd(n):
         ir_data_new['B1'] = pd.Series(list(ir_data['B']) + [ 1, -1])
         ir_data_new['B2'] = pd.Series(list(ir_data['B']) + [-1,  1])
 
-        operations_new += [Rotation(label="C2'", axis=[1, 0, 0], order=2), Reflection(label='sd', axis=[1, 0, 0])]
+        operations_new += [Rotation(label="C2'", axis=[np.sin(np.pi/(2*n)), np.cos(np.pi/(2*n)), 0], order=2),
+                           Reflection(label='sd', axis=[0, 1, 0])]
 
         for data in ir_data.keys():
             if data.startswith('E'):
                 ir_data_new[data] = pd.Series(list(ir_data[data]) + [0, 0])
 
-        multiplicites = ir_data.multiplicities + [n, n]
+        multiplicities = ir_data.multiplicities + [n, n]
 
         if n == 2:
-            rotations = ['E', 'E', 'A2']
-            translations = ['E', 'E', 'B2']
+            rotations = ['E', 'A2']
+            translations = ['E', 'B2']
         else:
-            rotations = ['E{}'.format(n-1), 'E{}'.format(n-1), 'A2']
-            translations = ['E1', 'E1', 'B2']
+            rotations = ['E{}'.format(n-1), 'A2']
+            translations = ['E1', 'B2']
     else:
         ir_data = get_dn(n)
         operations_new = ir_data.operations
@@ -631,10 +634,9 @@ def get_dnd(n):
         ir_data_new_u["A1u"] = pd.Series(list(ir_data['A1']) + [-1, -1])
         ir_data_new_u["A2u"] = pd.Series(list(ir_data['A2']) + [-1, 1])
 
-        multiplicites = [1] + [2]*((n-1)//2) + [n, 1] + [2]*((n-1)//2) + [n]
+        multiplicities = [1] + [2]*((n-1)//2) + [n, 1] + [2]*((n-1)//2) + [n]
 
-        operations_new += [Inversion(label='i'),
-                           Reflection(label='sd', axis=[1, 0, 0])]
+        operations_new += [Inversion(label='i'), Reflection(label='sd', axis=[np.cos(np.pi/(2*n)), np.sin(np.pi/(2*n)), 0])]
 
         for data in ir_data.keys():
             if data.startswith('E'):
@@ -681,18 +683,18 @@ def get_dnd(n):
             rotations = ["A1g", "A2g", "A2g"]
             translations = ["A1'", "A2'", "A2''"]
         elif n == 3:
-            rotations = ["Eg", "Eg", "A2g"]
-            translations = ["Eu", "Eu", "A2u"]
+            rotations = ["Eg", "A2g"]
+            translations = ["Eu", "A2u"]
         else:
-            rotations = ["E1g", "E1g", "A2g"]
-            translations = ["E1u", "E1u", "A2u"]
+            rotations = ["E1g", "A2g"]
+            translations = ["E1u", "A2u"]
 
     return CharTable('D{}d'.format(n),
                      operations_new,
                      ir_data_new,
                      rotations=rotations,  # x, y, z
                      translations=translations,  # Rx, Ry, Rz
-                     multiplicities=multiplicites)
+                     multiplicities=multiplicities)
 
 
 def get_table_from_label(label):
